'use strict';

var module = angular.module('SubmanagerWeb');
module.factory('APIInterceptor', ['$location', '$rootScope', function ($location, $rootScope) {
    return {
        'request': function (config) {

            return config;
        },
        'responseError': function (response) {
            console.log("responseError");
            console.log(response);
            return response;
        },
        'response': function (response) {
            // 只定义三种错误，200-成功，500-错误，显示消息，401-错误，清空登录信息并跳转到登录
            if (response.headers()['r']) {
                var data = angular.fromJson(response.data);
                if (data.status === 401) {
                    $rootScope.$broadcast('unauthorized');
                    return {};
                } else {
                    return data;
                }
            } else {
                return response;
            }
        }
    };
}]);

module.config(['$httpProvider', function ($httpProvider) {
    $httpProvider.interceptors.push('APIInterceptor');
}]);

module.service('HttpService', ['$http', function ($http) {
    var service = this;

    /**
     * 登录
     * @param credentials
     * @returns {*}
     */
    service.login = function (credentials) {
        return $http.post('/login', credentials);
    };

    /**
     * 退出登录
     * @returns {*}
     */
    service.logout = function () {
        return $http.post('/logout');
    };

    /**
     * 获取主机连接状态
     * @param credentials
     * @returns {*}
     */
    service.getProperty = function () {
        return $http.get('/api/property');
    };

    /**
     * 设置主机key
     * @param body
     * @returns {*}
     */
    service.setProperty = function (body) {
        return $http.post('/api/property', body);
    };

    /**
     * 重新连接
     * @returns {*}
     */
    service.reconnection = function () {
        return $http.post('/api/property/reconnection', {});
    };

    /**
     * 拉取密码
     * @returns {*}
     */
    service.pullPassword = function () {
        return $http.post('/api/property/pullPassword');
    };

    /**
     * 查看终端机是否能被连通
     * @param ip
     * @returns {*}
     */
    service.nodeReachable = function (ip) {
        return $http.get('/api/node/reachable/' + ip);
    };

    /**
     * 添加or修改终端机
     * @param node
     * @returns {*}
     */
    service.saveNode = function (node) {
        return $http.post('/api/node', node);
    };

    /**
     * 删除终端机
     * @param nodeId
     * @returns {*}
     */
    service.deleteNode = function (nodeId) {
        return $http.delete('/api/node/' + nodeId);
    };

    /**
     * 获取终端机详情
     * @param nodeId
     * @returns {*}
     */
    service.getNode = function (nodeId) {
        return $http.get('/api/node/' + nodeId);
    };

    /**
     * 获取终端机列表
     * @returns {*}
     */
    service.getNodes = function () {
        return $http.get('/api/node');
    };


    /**
     * 添加or修改终端机用户
     * @param nodeuser
     * @returns {*}
     */
    service.saveNodeuser = function (nodeuser) {
        return $http.post('/api/nodeuser', nodeuser);
    };

    /**
     * 删除终端机用户
     * @param id
     * @returns {*}
     */
    service.deleteNodeuser = function (id) {
        return $http.delete('/api/nodeuser/' + id);
    };

    /**
     * 获取终端机用户详情
     * @param id 终端机用户id
     * @returns {*}
     */
    service.getNodeuser = function (id) {
        return $http.get('/api/nodeuser/' + id);
    };

    /**
     * 获取终端机用户列表
     * @param nodeId 终端机id
     * @returns {*}
     */
    service.getNodeusers = function (nodeId) {
        return $http.get('/api/nodeusers/' + nodeId);
    };
}]);