'use strict';

angular.module('SubmanagerWeb').controller('MainCtrl', MainController);

MainController.$inject = ['$location', '$rootScope', 'HttpService', 'AppContext', '$interval', '$scope', 'layer'];

function MainController($location, $rootScope, HttpService, AppContext, $interval, $scope, layer) {
    var main = this;

    main.attribute = {"online": false};
    main.currentUser = AppContext.getCurrentUser();

    /**
     * 退出登录
     */
    main.logout = function () {
        HttpService.logout().then(function (response) {
            if (response.status === 200) {
                $rootScope.$broadcast('unauthorized');
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
        });
    };

    /**
     * 重新连接
     */
    main.reconnection = function () {
        HttpService.reconnection().then(function (response) {
            if (response.status === 200) {
                layer.msg('重新连接中', {icon: 6});
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
        });
    };

    /**
     * 拉取密码
     */
    main.pullPassword = function () {
        HttpService.pullPassword().then(function (response) {
            if (response.status === 200) {
                layer.msg('拉取数据中，请稍后', {icon: 6});
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
        });
    };

    /**
     * 获取属性
     */
    main.getProperty = function () {
        if (main.currentUser) {
            HttpService.getProperty().then(function (response) {
                if (response.status === 200) {
                    main.attribute = response.result;
                } else {
                }
            });
        }
    };
    main.getProperty();


    /**
     * 登录事件
     */
    $rootScope.$on('authorized', function () {
        main.currentUser = AppContext.getCurrentUser();
        main.getProperty();
    });

    /**
     * 退出登录事件
     */
    $rootScope.$on('unauthorized', function () {
        main.currentUser = AppContext.setCurrentUser(null);
        $location.path('/login');
    });

    /**
     * 定时刷新
     */
    $interval(function () {
        main.getProperty();
    }, 5000);
}