'use strict';

angular.module('SubmanagerWeb').controller('NodeCtrl', NodeController);

NodeController.$inject = ['$location', '$scope', 'HttpService', 'layer'];

function NodeController($location, $scope, HttpService, layer) {
    $scope.getNodes = function () {
        HttpService.getNodes().then(function (response) {
            if (response.status === 200) {
                $scope.nodes = response.result;
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
        });
    };

    /**
     * 删除
     * @param id
     */
    $scope.delete = function (id) {
        layer.confirm('确定要删除吗?', {
            btn: ['确认', '取消']
        }, function (index) {
            HttpService.deleteNode(id).then(function (response) {
                if (response.status === 200) {
                    layer.close($scope.nodeFormDailog);
                } else {
                    if (response.message) {
                        layer.msg(response.message, {icon: 5});
                    }
                }
                $scope.getNodes();
            });
            layer.close(index);
        });
    };

    /**
     * 添加or修改
     */
    $scope.save = function (node) {
        HttpService.saveNode(node).then(function (response) {
            if (response.status === 200) {
                layer.close($scope.nodeFormDailog);
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
            $scope.getNodes();
        });
    };

    /**
     * 打开表单窗口
     * @param id
     */
    $scope.openNodeForm = function (id) {
        if (id) {
            HttpService.getNode(id).then(function (response) {
                if (response.status === 200) {
                    $scope.node = response.result;
                    $scope.nodeFormDailog = layer.open({
                        type: 1,
                        title: '修改终端机',
                        area: ['600px', '400px'],
                        contentUrl: 'app/templates/node/node-form.html',
                        scope: $scope
                    });
                } else {
                    if (response.message) {
                        layer.msg(response.message, {icon: 5});
                    }
                }
            });
        } else {
            $scope.node = {osName: 'windows'};
            $scope.nodeFormDailog = layer.open({
                type: 1,
                title: '添加终端机',
                area: ['600px', '400px'],
                contentUrl: 'app/templates/node/node-form.html',
                scope: $scope
            });
        }
    };

    /**
     * 关闭表单窗口
     */
    $scope.closeNodeForm = function () {
        layer.close($scope.nodeFormDailog);
    };

    /**
     * 终端机是否能连通
     * @param ip
     */
    $scope.nodeReachable = function (ip) {
        layer.msg('检测中', {
            icon: 16, shade: 0.01
        });
        HttpService.nodeReachable(ip).then(function (response) {
            layer.closeAll('loading');
            if (response.status === 200) {
                var status = response.result.status;
                if (status) {
                    layer.msg(ip + '，连接成功', {icon: 1});
                } else {
                    layer.msg(ip + '，连接失败', {icon: 5});
                }
            } else {
                if (response.message) {
                    layer.msg(response.message, {icon: 5});
                }
            }
        });
    };


    $scope.getNodes();
}